{% macro modal(id, title) %}

    <!-- Create modal -->
    <div id="{{ id }}" class="modal fade" role="dialog" tabindex="-1">
        <div class="modal-dialog modal-lg" role="document">

            <!-- Modal content-->
            <div class="modal-content">

                <div class="modal-header">
                    <h4 class="modal-title">{{ title }}</h4>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>

                <!-- Modal body -->
                <div class="modal-body" id="{{ id }}-body">

                    {{ caller() }}

                </div>

                <div class="modal-footer">
                    <button type="button" class="btn btn-default" data-bs-dismiss="modal">
                        Close
                    </button>
                </div>
            </div>
        </div>
    </div>

{% endmacro %}