{% macro primer_descr(primer) %}

  <div class="card">
    <div class="card-body">
      <h5 class="card-title">{{ primer.label }}</h5>
      <h6 class="card-subtitle mb-2 text-muted">ID: {{ primer.id }}</h6>
      <p class="card-text">{{ primer.description }}</p>
      <a href="#" class="card-link">Edit</a>
    </div>
  </div>

{% endmacro %}