{% macro toast(title, content) %}

    <div class="toast show"
         role="alert"
         data-bs-animation="true"
         data-bs-autohide="true"
         aria-live="assertive"
         aria-atomic="true">
        <div class="toast-header">
            <strong class="me-auto">{{ title }}</strong>
            <small>11 mins ago</small>
            <button type="button" class="btn-close" data-bs-dismiss="toast" aria-label="Close"></button>
        </div>
        <div class="toast-body fw-lighter">
            {{ content}}
        </div>
    </div>

{% endmacro %}