{% extends 'base-site-authenticated.html' %}

{% import 'macros/navbar.html' as nav with context %}


{% block content %}

    <div class="container">

        <div class="row">

            <div class="col-2">

                <ul class="nav flex-column sticky-top my-3">
                    {{ nav.link('imports.index', 'Pending imports') }}
                    {{ nav.link('imports.index', 'Archived imports') }}
                </ul>

            </div>

            <div class="col-10">

                {{ flash.flash() }}

                {% block content2 %}{% endblock %}

            </div>

        </div>

    </div>

{% endblock %}