{% import 'macros/flash.html' as flash %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Labbase2 - {{ title }}</title>

    {% block stylesheets %}

        <!-- Bootstrap CSS -->
        <link rel="stylesheet" href="{{ url_for('static', filename='vendors/bootstrap-5.2.3-dist/css/bootstrap.min.css') }}">
        <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.3/font/bootstrap-icons.min.css">
        <!-- Lightbox CSS -->
        <link rel="stylesheet" href="{{ url_for('static', filename='vendors/magnific-popup/css/magnific-popup.css') }}">
        <!-- jQuery UI CSS -->
        <link rel="stylesheet" href="{{ url_for('static', filename='vendors/jquery-ui/css/jquery-ui.min.css') }}">
        <link rel="stylesheet" href="{{ url_for('static', filename='vendors/jquery-ui/css/jquery-ui.structure.min.css') }}">
        <link rel="stylesheet" href="{{ url_for('static', filename='vendors/jquery-ui/css/jquery-ui.theme.min.css') }}">
        <!-- Custom CSS -->
        <link rel="stylesheet" href="{{ url_for('static', filename='css/style.css') }}">

    {% endblock %}

    {% block scripts_head %}{% endblock %}

</head>
<body>

<!-- Main content -->
{% block body %}
{% endblock %}


<!-- JavaScript -->
{% block scripts %}

    <!-- Additional scripts -->
    <script src="{{ url_for('static', filename='vendors/jquery-3.7.1/js/jquery-3.7.1.min.js') }}"></script>
    <script src="{{ url_for('static', filename='vendors/bootstrap-5.2.3-dist/js/bootstrap.bundle.min.js') }}"></script>
    <script src="{{ url_for('static', filename='vendors/magnific-popup/js/jquery.magnific-popup.min.js') }}"></script>
    <script src="https://unpkg.com/@popperjs/core@2"></script>

{% endblock %}


</body>
</html>


