{% extends 'base-site-authenticated.html' %}
{% import 'macros/flash.html' as flash %}


{% block content %}

    <div class="container">

        {{ flash.flash() }}

        <h1 class="mt-4">Welcome to Labbase2</h1>

    </div>

{% endblock %}