{% extends 'base-site-entities.html' %}

{% from "stock_solutions/form.html" import stock_solution_add_form %}
{% from 'stock_solutions/table.html' import table %}


{% block download %}

{% endblock %}