{% extends 'auth/base-site-user.html' %}
{% from 'auth/form.html' import register_user_form %}


{% block content2 %}

    <h1 class="mt-3 mb-4">Register new user</h1>

    <div class="bg-white rounded border p-3 my-3">

        {{ register_user_form(form, 'auth.register') }}

    </div>

{% endblock %}
