{% extends 'base-site-entities.html' %}

{% from 'oligonucleotides/form.html' import primer_add_form %}
{% from 'oligonucleotides/table.html' import table %}


{% block import %}

    <button type="button"
            class="btn btn-sm btn-success"
            data-bs-toggle="modal"
            data-bs-target="#modal-edit-primer--1">
        <i class="fa-solid fa-plus"></i>
    </button>

{% endblock %}


{% block download %}

    <a class="dropdown-item small fw-lighter" href="{{ url_for(".export", format_="csv", **args) }}">
        <i class="bi bi-filetype-csv me-1"></i> Download CSV file
    </a>
    <a class="dropdown-item small fw-lighter" href="{{ url_for(".export", format_="json", **args) }}">
        <i class="bi bi-filetype-json me-1"></i> Down JSON file
    </a>
    <a class="dropdown-item small fw-lighter" href="{{ url_for(".export", format_="fasta", **args) }}">
        <i class="bi bi-file-earmark me-1"></i> Download FASTA file
    </a>

{#    <li><hr class="dropdown-divider"></li>#}
{##}
{#    <a class="dropdown-item small fw-lighter" href="{{ url_for(".export", format_="fasta", **args) }}">#}
{#        <i class="bi bi-file-earmark-zip me-1"></i> Download ZIP archive#}
{#    </a>#}

{% endblock %}


{% block scripts %}

    {{ super() }}

    {{ upload_file_form(import_file_form, url_for("imports.upload", type_="oligonucleotide")) }}
    {{ primer_add_form(add_form, ".add", "POST", -1) }}

{% endblock %}